@@ -1,22 +1,29 @@
-#include <stdbool.h>
-#include <stdint.h>
+#include <cstdbool>
+#include <cstdint>
+#include <cstdlib>
 
 // You'll want to change this to reflect the capacity
 // you've built `libstaticvec` with, if not using the default
-// `capacity_32` crate feature.
-#define VECTOR_CAPACITY 32
+// `capacity_16` crate feature.
+static constexpr size_t VECTOR_CAPACITY = 16;
 
-typedef const void *VoidPtr;
+using VoidPtr = const void *;
 
-typedef struct CStaticVec {
+extern "C" {
+// TODO: Figure out if there's any possible way to accept more than
+// just opaque pointers.
+struct CStaticVec {
+private:
   VoidPtr data[VECTOR_CAPACITY];
   size_t length;
-} CStaticVec;
+};
 
-typedef struct COption {
+// TODO: Maybe make this an actual union or something? Might not be worth
+// it though.
+struct COption {
   bool is_some;
   VoidPtr value;
-} COption;
+};
 
 size_t staticvec_capacity(const CStaticVec *vec);
 
@@ -42,4 +49,7 @@ VoidPtr staticvec_remove(CStaticVec *vec, size_t index);
 
 COption staticvec_remove_item(CStaticVec *vec, VoidPtr item);
 
-void staticvec_set(CStaticVec *vec, size_t index, VoidPtr item);
\ No newline at end of file
+void staticvec_set(CStaticVec *vec, size_t index, VoidPtr item);
+
+size_t staticvec_size_in_bytes(const CStaticVec *vec);
+}
\ No newline at end of file
